@@ -13,17 +13,13 @@
 #' # Call the function
 #' res <- dominated(x, Y)
 #'
-#' @author Fabrice Zaoui
+#' @author Alban de Lavenne, Fabrice Zaoui
 
 dominated <- function(x, Y) {
 
-  # Predicate function indicating which rows of the matrix Y are dominated by the vector (row) x
-  X <- matrix(rep(x, dim(Y)[1]), ncol = dim(Y)[2], byrow = TRUE)
+  if (!is.double(x)) {storage.mode(x) <- 'double'}
+  if (!is.double(Y)) {storage.mode(Y) <- 'double'}
+  res <- .Call(c_dominated, x, Y)
+  return(res == 1)
 
-  D <- X - Y
-  nobj <- dim(D)[2]
-  res1 <- rowSums(D >= 0) == nobj
-  res2 <- rowSums(D > 0) > 0
-
-  return(res1 & res2)
 }
